package event

import "encoding/xml"

// InfoType 说明
const (
	// INFO_TYPE_COMPONENT_VERIFY_TICKET 验证票据
	INFO_TYPE_COMPONENT_VERIFY_TICKET = "component_verify_ticket"

	// INFO_TYPE_AUTHORIZED 授权成功
	INFO_TYPE_AUTHORIZED = "authorized"

	// INFO_TYPE_UPDATEAUTHORIZED 更新授权
	INFO_TYPE_UPDATEAUTHORIZED = "updateauthorized"

	// INFO_TYPE_UNAUTHORIZED 取消授权
	INFO_TYPE_UNAUTHORIZED = "unauthorized"
)

// CDATA 解析 xml cdata 字段
type CDATA struct {
	Value string `xml:",cdata"`
}

// ReceivedEncryptMessage 待解密数据
type ReceivedEncryptMessage struct {
	XMLName    xml.Name `xml:"xml"`
	ToUserName string   `xml:"ToUserName"`
	Encrypt    string   `xml:"Encrypt"`
}

type SendEncryptMessage struct {
	XMLName      xml.Name `xml:"xml"`
	Encrypt      CDATA    `xml:"Encrypt"`
	MsgSignature string   `xml:"MsgSignature"`
	TimeStamp    int64    `xml:"TimeStamp"`
	Nonce        string   `xml:"Nonce"`
}

// AuthEvent 事件
type AuthEvent struct {
	XMLName    xml.Name `xml:"xml"`
	AppID      string   `xml:"AppId"`
	CreateTime int64    `xml:"CreateTime"`
	InfoType   string   `xml:"InfoType"`
}

// ComponentVerifyTicketEvent 令牌授权事件
type ComponentVerifyTicketEvent struct {
	AuthEvent
	ComponentVerifyTicket string `xml:"ComponentVerifyTicket"`
}

// AuthorizedEvent 授权成功, 与更新授权字段属性一致
type AuthorizedEvent struct {
	AuthEvent
	AuthorizerAppID              string `xml:"AuthorizerAppid"`
	AuthorizationCode            string `xml:"AuthorizationCode"`
	AuthorizationCodeExpiredTime int64  `xml:"AuthorizationCodeExpiredTime"`
	PreAuthCode                  string `xml:"PreAuthCode"`
}

// UnauthorizedEvent 取消授权
type UnauthorizedEvent struct {
	AuthEvent
	AuthorizerAppID string `xml:"AuthorizerAppid"`
}

// AuthorizerEvent 公众号或者小程序事件
type AuthorizerEvent struct {
	XMLName      xml.Name `xml:"xml"`
	ToUserName   CDATA    `xml:"ToUserName"`
	FromUserName CDATA    `xml:"FromUserName"`
	CreateTime   int64    `xml:"CreateTime"`
	MsgType      CDATA    `xml:"MsgType"`
	Event        CDATA    `xml:"Event"`
}
